@@ -1,7 +1,7 @@
 params <-
   list(EVAL = TRUE)
 
-## ----echo = FALSE-------------------------------------------------------
+## ----echo = FALSE----------------------------------------------------------------
 knitr::opts_chunk$set(
   collapse = TRUE,
   comment = "#>",
@@ -11,7 +11,7 @@ knitr::opts_chunk$set(
 )
 
 
-## ----setup, include=FALSE-----------------------------------------------
+## ----setup, include=FALSE--------------------------------------------------------
 knitr::opts_chunk$set(
   echo = TRUE,
   dpi = 100,
@@ -25,7 +25,7 @@ library(ggplot2)
 theme_set(theme_bw(base_size = 12, base_family = "serif"))
 
 
-## -----------------------------------------------------------------------
+## --------------------------------------------------------------------------------
 simdat <- sim_mvgam(
   n_series = 4,
   T = 24,
@@ -34,19 +34,19 @@ simdat <- sim_mvgam(
 head(simdat$data_train, 16)
 
 
-## -----------------------------------------------------------------------
+## --------------------------------------------------------------------------------
 class(simdat$data_train$series)
 levels(simdat$data_train$series)
 
 
-## -----------------------------------------------------------------------
+## --------------------------------------------------------------------------------
 all(
   levels(simdat$data_train$series) %in%
     unique(simdat$data_train$series)
 )
 
 
-## -----------------------------------------------------------------------
+## --------------------------------------------------------------------------------
 summary(glm(
   y ~ series + time,
   data = simdat$data_train,
@@ -54,7 +54,7 @@ summary(glm(
 ))
 
 
-## -----------------------------------------------------------------------
+## --------------------------------------------------------------------------------
 summary(mgcv::gam(
   y ~ series + s(time, by = series),
   data = simdat$data_train,
@@ -62,7 +62,7 @@ summary(mgcv::gam(
 ))
 
 
-## -----------------------------------------------------------------------
+## --------------------------------------------------------------------------------
 gauss_dat <- data.frame(
   outcome = rnorm(10),
   series = factor("series1", levels = "series1"),
@@ -71,17 +71,17 @@ gauss_dat <- data.frame(
 gauss_dat
 
 
-## -----------------------------------------------------------------------
+## --------------------------------------------------------------------------------
 mgcv::gam(outcome ~ time, family = betar(), data = gauss_dat)
 
 
-## ----error=TRUE---------------------------------------------------------
+## ----error=TRUE------------------------------------------------------------------
 try({
   mvgam(outcome ~ time, family = betar(), data = gauss_dat)
 })
 
 
-## -----------------------------------------------------------------------
+## --------------------------------------------------------------------------------
 # A function to ensure all timepoints within a sequence are identical
 all_times_avail <- function(time, min_time, max_time) {
   identical(
@@ -116,7 +116,7 @@ if (any(checked_times$all_there == FALSE)) {
 }
 
 
-## -----------------------------------------------------------------------
+## --------------------------------------------------------------------------------
 bad_times <- data.frame(
   time = seq(1, 16, by = 2),
   series = factor("series_1"),
@@ -125,13 +125,13 @@ bad_times <- data.frame(
 bad_times
 
 
-## ----error = TRUE-------------------------------------------------------
+## ----error = TRUE----------------------------------------------------------------
 try({
   get_mvgam_priors(outcome ~ 1, data = bad_times, family = gaussian())
 })
 
 
-## -----------------------------------------------------------------------
+## --------------------------------------------------------------------------------
 bad_times %>%
   dplyr::right_join(expand.grid(
     time = seq(
@@ -144,13 +144,13 @@ bad_times %>%
 good_times
 
 
-## ----error = TRUE-------------------------------------------------------
+## ----error = TRUE----------------------------------------------------------------
 try({
   get_mvgam_priors(outcome ~ 1, data = good_times, family = gaussian())
 })
 
 
-## -----------------------------------------------------------------------
+## --------------------------------------------------------------------------------
 bad_levels <- data.frame(
   time = 1:8,
   series = factor(
@@ -166,23 +166,23 @@ bad_levels <- data.frame(
 levels(bad_levels$series)
 
 
-## ----error = TRUE-------------------------------------------------------
+## ----error = TRUE----------------------------------------------------------------
 try({
   get_mvgam_priors(outcome ~ 1, data = bad_levels, family = gaussian())
 })
 
 
-## -----------------------------------------------------------------------
+## --------------------------------------------------------------------------------
 setdiff(levels(bad_levels$series), unique(bad_levels$series))
 
 
-## -----------------------------------------------------------------------
+## --------------------------------------------------------------------------------
 bad_levels %>%
   dplyr::mutate(series = droplevels(series)) -> good_levels
 levels(good_levels$series)
 
 
-## ----error = TRUE-------------------------------------------------------
+## ----error = TRUE----------------------------------------------------------------
 try({
   get_mvgam_priors(
     outcome ~ 1,
@@ -192,7 +192,7 @@ try({
 })
 
 
-## -----------------------------------------------------------------------
+## --------------------------------------------------------------------------------
 miss_dat <- data.frame(
   outcome = rnorm(10),
   cov = c(NA, rnorm(9)),
@@ -202,7 +202,7 @@ miss_dat <- data.frame(
 miss_dat
 
 
-## ----error = TRUE-------------------------------------------------------
+## ----error = TRUE----------------------------------------------------------------
 try({
   get_mvgam_priors(
     outcome ~ cov,
@@ -212,7 +212,7 @@ try({
 })
 
 
-## -----------------------------------------------------------------------
+## --------------------------------------------------------------------------------
 miss_dat <- list(
   outcome = rnorm(10),
   series = factor("series1", levels = "series1"),
@@ -222,7 +222,7 @@ miss_dat$cov <- matrix(rnorm(50), ncol = 5, nrow = 10)
 miss_dat$cov[2, 3] <- NA
 
 
-## ----error=TRUE---------------------------------------------------------
+## ----error=TRUE------------------------------------------------------------------
 try({
   get_mvgam_priors(
     outcome ~ cov,
@@ -232,7 +232,7 @@ try({
 })
 
 
-## ----fig.alt = "Plotting time series features for GAM models in mvgam"----
+## ----fig.alt = "Plotting time series features for GAM models in mvgam"-----------
 plot_mvgam_series(
   data = simdat$data_train,
   y = "y",
@@ -240,7 +240,7 @@ plot_mvgam_series(
 )
 
 
-## ----fig.alt = "Plotting time series features for GAM models in mvgam"----
+## ----fig.alt = "Plotting time series features for GAM models in mvgam"-----------
 plot_mvgam_series(
   data = simdat$data_train,
   y = "y",
@@ -248,7 +248,7 @@ plot_mvgam_series(
 )
 
 
-## ----fig.alt = "Plotting time series features for GAM models in mvgam"----
+## ----fig.alt = "Plotting time series features for GAM models in mvgam"-----------
 plot_mvgam_series(
   data = simdat$data_train,
   newdata = simdat$data_test,
@@ -257,12 +257,12 @@ plot_mvgam_series(
 )
 
 
-## -----------------------------------------------------------------------
+## --------------------------------------------------------------------------------
 data("all_neon_tick_data")
 str(dplyr::ungroup(all_neon_tick_data))
 
 
-## -----------------------------------------------------------------------
+## --------------------------------------------------------------------------------
 plotIDs <- c(
   "SCBI_013",
   "SCBI_002",
@@ -275,7 +275,7 @@ plotIDs <- c(
 )
 
 
-## -----------------------------------------------------------------------
+## --------------------------------------------------------------------------------
 model_dat <- all_neon_tick_data %>%
   dplyr::ungroup() %>%
   dplyr::mutate(target = ixodes_scapularis) %>%
@@ -284,7 +284,7 @@ model_dat <- all_neon_tick_data %>%
   dplyr::mutate(epiWeek = as.numeric(epiWeek))
 
 
-## -----------------------------------------------------------------------
+## --------------------------------------------------------------------------------
 model_dat %>%
   # Create all possible combos of plotID, Year and epiWeek;
   # missing outcomes will be filled in as NA
@@ -302,7 +302,7 @@ model_dat %>%
   ) -> model_dat
 
 
-## -----------------------------------------------------------------------
+## --------------------------------------------------------------------------------
 model_dat %>%
   dplyr::mutate(
     series = plotID,
@@ -316,7 +316,7 @@ model_dat %>%
   dplyr::arrange(Year, epiWeek, series) -> model_dat
 
 
-## -----------------------------------------------------------------------
+## --------------------------------------------------------------------------------
 model_dat %>%
   dplyr::ungroup() %>%
   dplyr::group_by(series) %>%
@@ -325,11 +325,11 @@ model_dat %>%
   dplyr::ungroup() -> model_dat
 
 
-## -----------------------------------------------------------------------
+## --------------------------------------------------------------------------------
 levels(model_dat$series)
 
 
-## ----error=TRUE---------------------------------------------------------
+## ----error=TRUE------------------------------------------------------------------
 try({
   get_mvgam_priors(
     y ~ 1,
@@ -339,11 +339,10 @@ try({
 })
 
 
-## -----------------------------------------------------------------------
+## --------------------------------------------------------------------------------
 testmod <- mvgam(
-  y ~
-    s(epiWeek, by = series, bs = "cc") +
-      s(series, bs = "re"),
+  y ~ s(epiWeek, by = series, bs = "cc") +
+    s(series, bs = "re"),
   trend_model = AR(),
   data = model_dat,
   backend = "cmdstanr",
@@ -351,9 +350,9 @@ testmod <- mvgam(
 )
 
 
-## -----------------------------------------------------------------------
+## --------------------------------------------------------------------------------
 str(testmod$model_data)
 
 
-## -----------------------------------------------------------------------
+## --------------------------------------------------------------------------------
 stancode(testmod)
